.. image:: http://cloud.github.com/downloads/ask/pyes/pyes_favicon_128.png
   :class: pyeslogo

=================================
 PyES - Python Elastic Search
=================================

Contents:

.. toctree::
    :maxdepth: 2

    faq
    reference/index
    changelog
    links


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

